==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/it.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Contatti",
"Save" => "Salva",
"Uploading..." => "Caricamento in corso...",
"Importing..." => "Importazione in corso...",
"Preparing..." => "Preparazione in corso...",
"Imported {count} of {total} contacts" => "Importati {count} di {total} contatti",
"Imported {imported} contacts. {failed} failed." => "Importati {imported} contatti. {failed} non riusciti.",
"An address book called {name} already exists" => "Una rubrica con nome {name} esiste già",
"Failed adding address book: {error}" => "Aggiunta della rubrica non riuscita: {error}",
"Failed loading address books: {error}" => "Caricamento rubriche non riuscito: {error}",
"Indexing contacts" => "Indicizzazione dei contatti",
"Unrecoverable error loading address books: {msg}" => "Errore irreversibile durante il caricamento delle rubriche: {msg}",
"Error." => "Errore.",
"Add to..." => "Aggiungi a...",
"Remove from..." => "Rimuovi da...",
"Add group..." => "Aggiungi gruppo...",
"Invalid URL: \"{url}\"" => "URL non valido: \"{url}\"",
"There was an error opening a mail composer." => "Si è verificato un errore durante l'apertura del compositore.",
"Invalid email: \"{url}\"" => "Email non valida: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Unione non riuscita. Impossibile trovare il contatto: {id}",
"Merge failed." => "Unione non riuscita.",
"Merge failed. Error saving contact." => "Unione non riuscita. Errore durante il salvataggio del contatto.",
"Select photo" => "Seleziona la foto",
"Network or server error. Please inform administrator." => "Errore di rete o del server. Informa l'amministratore.",
"Error adding to group." => "Errore durante l'aggiunta al gruppo.",
"Error removing from group." => "Errore durante la rimozione dal gruppo.",
"Error setting {name} as favorite." => "Errore durante l'impostazione di {name} come preferito.",
"Merge contacts" => "Unisci contatti",
"Cancel" => "Annulla",
"Add group" => "Aggiungi gruppo",
"OK" => "OK",
"Could not find contact: {id}" => "Impossibile trovare il contatto: {id}",
"No files selected for upload." => "Nessun file selezionato per l'invio",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Il file che stai cercando di inviare supera la dimensione massima per l'invio dei file su questo server.",
"Edit profile picture" => "Modifica l'immagine del profilo",
"Crop photo" => "Ritaglia foto",
"Is this correct?" => "È corretto?",
"Error parsing date: {date}" => "Errore durante l'elaborazione della data: {date}",
"# groups" => "# gruppi",
"Error parsing birthday {bday}: {error}" => "Errore durante l'elaborazione della data di nascita {bday}: {error}",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Alcuni contatti sono marcati per l'eliminazione, ma non sono stati ancora rimossi. Attendi fino al completamento dell'operazione.",
"Click to undo deletion of {num} contacts" => "Un clic per annullare l'eliminazione di {num} contatti",
"Cancelled deletion of {num} contacts" => "Eliminazione di {num} contatti annullata",
"Add" => "Aggiungi",
"Contact is already in this group." => "Il contatto è già in questo gruppo.",
"Contacts are already in this group." => "I contatti sono già in questo gruppo.",
"Couldn't get contact list." => "Impossibile ottenere l'elenco dei contatti.",
"Contact is not in this group." => "Il contatto non è in questo gruppo.",
"Contacts are not in this group." => "I contatti non sono in questo gruppo.",
"Failed renaming group: {error}" => "Rinomina gruppo non riuscita: {error}",
"A group named {group} already exists" => "Un gruppo con nome {group} esiste già",
"You can drag groups to\narrange them as you like." => "Puoi trascinare i gruppi per\norganizzarli come preferisci.",
"Failed adding group: {error}" => "Aggiunta gruppo non riuscita: {error}",
"All" => "Tutti",
"Favorites" => "Preferiti",
"Shared by {owner}" => "Condiviso da {owner}",
"Not grouped" => "Non raggruppati",
"Failed loading groups: {error}" => "Caricamento gruppi non riuscito: {error}",
"Please choose the addressbook" => "Scegli la rubrica",
"Import into..." => "Importa in...",
"Error loading import template" => "Errore durante il caricamento del modello di importazione",
"Import contacts" => "Importa contatti",
"Import" => "Importa",
"Import done" => "Importazione completata",
"Close" => "Chiudi",
"Error" => "Errore",
"Displayname cannot be empty." => "Il nome visualizzato non può essere vuoto.",
"Show CardDav link" => "Mostra collegamento CardDav",
"Show read-only VCF link" => "Mostra collegamento VCF in sola lettura",
"Download" => "Scarica",
"Edit" => "Modifica",
"Delete" => "Elimina",
"More..." => "Altro...",
"Less..." => "Meno...",
"Server error! Please inform system administator" => "Errore del server. Informa l'amministratore di sistema",
"Failed loading photo: {error}" => "Caricamento foto non riuscito: {error}",
"You do not have permissions to see this contacts" => "Non hai i permessi per vedere questo contatto",
"Contact not found" => "Contatto non trovato",
"You do not have permissions to see these contacts" => "Non hai i permessi per vedere questi contatti",
"You do not have permissions add contacts to the address book" => "Non hai i permessi per aggiungere contatti alla rubrica",
"The backend for this address book does not support adding contacts" => "Il motore per questa rubrica non supporta l'aggiunta di contatti",
"You do not have permissions to delete this contact" => "Non hai i permessi per eliminare questo contatto",
"The backend for this address book does not support deleting contacts" => "Il motore per questa rubrica non supporta l'eliminazione di contatti",
"Unknown error" => "Errore sconosciuto",
"The backend for this address book does not support updating" => "Il motore per questa rubrica non supporta l'aggiornamento",
"You don't have permissions to update the address book." => "Non hai i permessi per aggiornare la rubrica.",
"You don't have permissions to delete the address book." => "Non hai i permessi per eliminare la rubrica.",
"Address book not found" => "Rubrica non trovata.",
"You do not have permissions to see this contact" => "Non hai i permessi per vedere questo contatto",
"You do not have permissions to update this contact" => "Non hai i permessi per aggiornare questo contatto",
"The backend for this contact does not support updating it" => "Il motore per questo contatto non supporta l'aggiornamento",
"This backend not support adding contacts" => "Questo motore non supporta l'aggiunta di contatti",
"Property not found" => "Proprietà non trovata",
" Missing IM parameter for: " => "Parametro IM mancante per:",
"Unknown IM: " => "IM sconosciuto:",
"{name}'s Birthday" => "Data di nascita di {name}",
"Error creating address book" => "Errore durante la creazione della rubrica",
"Error updating address book" => "Errore durante l'aggiornamento della rubrica",
"You do not have permissions to delete the \"%s\" address book" => "Non hai i permessi per eliminare la rubrica \"%s\"",
"Error deleting address book" => "Errore durante l'eliminazione della rubrica",
"Error creating contact." => "Errore durante la creazione del contatto.",
"Error deleting contact." => "Errore durante l'eliminazione del contatto.",
"Error retrieving contact." => "Errore durante il recupero del contatto.",
"Error saving contact." => "Errore di salvataggio del contatto.",
"Error removing contact from other address book." => "Errore durante la rimozione del contatto da altre rubriche.",
"Couldn't find contact." => "Impossibile trovare il contatto.",
"No contact data in request." => "Non ci sono dati di contatto nella richiesta.",
"Error merging into contact." => "Errore durante l'unione al contatto.",
"Error saving contact to backend." => "Errore di salvataggio del contatto nel motore.",
"Property name is not set." => "Il nome della proprietà non è impostato.",
"Property checksum is not set." => "La proprietà del codice di controllo non è impostata.",
"Information about vCard is incorrect. Please reload the page." => "Informazioni sulla vCard non corrette. Ricarica la pagina.",
"Error updating contact" => "Errore durante l'aggiornamento del contatto",
"Error saving contact to backend" => "Errore durante il salvataggio del contatto nel motore",
"Error getting user photo" => "Errore durante il recupero della foto dell'utente",
"No file was uploaded. Unknown error" => "Nessun file è stato inviato. Errore sconosciuto",
"There is no error, the file uploaded with success" => "Non ci sono errori, il file è stato caricato correttamente",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Il file inviato supera la direttiva upload_max_filesize nel php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Il file inviato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
"The uploaded file was only partially uploaded" => "Il file è stato caricato solo parzialmente",
"No file was uploaded" => "Nessun file è stato caricato",
"Missing a temporary folder" => "Manca una cartella temporanea",
"Couldn't load temporary image: " => "Impossibile caricare l'immagine temporanea: ",
"Couldn't save temporary image: " => "Impossibile salvare l'immagine temporanea: ",
"No photo path was submitted." => "Non è stato inviato alcun percorso a una foto.",
"File doesn't exist:" => "Il file non esiste:",
"Error loading image." => "Errore di caricamento immagine.",
"Image has been removed from cache" => "L'immagine è stata rimossa dalla cache",
"Error creating temporary image" => "Errore durante la creazione dell'immagine temporanea",
"Error cropping image" => "Errore di ritaglio dell'immagine",
"Error resizing image" => "Errore di ridimensionamento dell'immagine",
"Error getting PHOTO property." => "Errore di recupero della proprietà FOTO.",
"No group name given." => "Nessun nome di gruppo fornito.",
"Error adding group." => "Errore durante l'aggiunta del gruppo.",
"No group name to rename from given." => "Non è stato fornito nessun nome per il gruppo da rinominare.",
"No group name to rename to given." => "Nessun nome gruppo di destinazione fornito.",
"Error renaming group." => "Errore durante la rinomina del gruppo.",
"Group ID missing from request." => "ID del gruppo mancante nella richiesta.",
"Group name missing from request." => "Nome del gruppo mancante nella richiesta.",
"Contact ID missing from request." => "ID del contatta mancante nella richiesta.",
"Failed to write to disk" => "Scrittura su disco non riuscita",
"Not enough storage available" => "Spazio di archiviazione insufficiente",
"Attempt to upload blacklisted file:" => "Tentativo di caricare un file della lista nera:",
"Error uploading contacts to storage." => "Errore di invio dei contatti in archivio.",
"Error moving file to imports folder." => "Errore durante lo spostamento del file nella cartella di importazione.",
"You do not have permissions to import into this address book." => "Non hai i permessi per importare in questa rubrica.",
"File name missing from request." => "Manca il nome del file nella richiesta.",
"Progress key missing from request." => "Manca la chiave di avanzamento nella richiesta.",
"Attempt to access blacklisted file:" => "Tentativo di accedere a un file della lista nera:",
"No contacts found in: " => "Nessun contatto trovato in:",
"No key is given." => "Nessuna chiave fornita.",
"No value is given." => "Nessun valore fornito.",
"Could not set preference: " => "Impossibile impostare la preferenza:",
"Contact" => "Contatto",
"Other" => "Altro",
"HomePage" => "Pagina principale",
"Jabber" => "Jabber",
"Internet call" => "Chiamata via Internet",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Lavoro",
"Home" => "Casa",
"Mobile" => "Cellulare",
"Text" => "Testo",
"Voice" => "Voce",
"Message" => "Messaggio",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Cercapersone",
"Internet" => "Internet",
"Friends" => "Amici",
"Family" => "Famiglia",
"New Contact" => "Nuovo contatto",
"Group name" => "Nome gruppo",
"New Group" => "Nuovo gruppo",
"Address books" => "Rubriche",
"Display name" => "Nome visualizzato",
"Add Address Book" => "Aggiungi rubrica",
"Select file..." => "Seleziona file...",
"(De-)select all" => "(De)seleziona tutto",
"Sort order" => "Ordinamento",
"First- Lastname" => "Nome Cognome",
"Last-, Firstname" => "Cognome, Nome",
"Groups" => "Gruppi",
"Favorite" => "Preferito",
"Merge selected" => "Unisci selezionati",
"Keyboard shortcuts" => "Scorciatoie da tastiera",
"Navigation" => "Navigazione",
"Next contact in list" => "Contatto successivo in elenco",
"Previous contact in list" => "Contatto precedente in elenco",
"Expand/collapse current addressbook" => "Espandi/Contrai la rubrica corrente",
"Next addressbook" => "Rubrica successiva",
"Previous addressbook" => "Rubrica precedente",
"Actions" => "Azioni",
"Refresh contacts list" => "Aggiorna l'elenco dei contatti",
"Add new contact" => "Aggiungi un nuovo contatto",
"Add new addressbook" => "Aggiungi una nuova rubrica",
"Delete current contact" => "Elimina il contatto corrente",
"<h3>You have no contacts in your address book or your address book is disabled.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>Non ci sono contatti nella tua rubrica o la rubrica è disabilitata.</h3><p>Aggiungi un nuovo contatto o importa contatti esistenti da un file VCF.</p>",
"Add contact" => "Aggiungi contatto",
"Delete group" => "Elimina gruppo",
"Rename group" => "Rinomina gruppo",
"Which contact should the data be merged into?" => "A quale contatto desideri unire i dati?",
"Delete the other(s) after successful merge?" => "Vuoi eliminare gli altri dopo il completamento dell'unione?",
"Compose mail" => "Componi messaggio",
"Delete current photo" => "Elimina la foto corrente",
"Edit current photo" => "Modifica la foto corrente",
"Upload new photo" => "Invia una nuova foto",
"Select photo from ownCloud" => "Seleziona la foto da ownCloud",
"Name" => "Nome",
"First name" => "Nome",
"Additional names" => "Nomi aggiuntivi",
"Last name" => "Cognome",
"Select groups" => "Seleziona gruppi",
"Select address book" => "Seleziona rubrica",
"Nickname" => "Pseudonimo",
"Enter nickname" => "Inserisci pseudonimo",
"Title" => "Titolo",
"Enter title" => "Inserisci il titolo",
"Organization" => "Organizzazione",
"Enter organization" => "Inserisci l'organizzazione",
"Birthday" => "Compleanno",
"Notes go here..." => "Le note vanno qui...",
"Export as VCF" => "Esporta come VCF",
"Add field..." => "Aggiungi campo...",
"Phone" => "Telefono",
"Email" => "Posta elettronica",
"Instant Messaging" => "Messaggistica istantanea",
"Address" => "Indirizzo",
"Note" => "Nota",
"Web site" => "Sito web",
"Delete contact" => "Elimina contatto",
"Preferred" => "Preferito",
"Please specify a valid email address." => "Specifica un indirizzo email valido",
"someone@example.com" => "qualcuno@esempio.com",
"Mail to address" => "Invia per email",
"Delete email address" => "Elimina l'indirizzo email",
"Enter phone number" => "Inserisci il numero di telefono",
"Delete phone number" => "Elimina il numero di telefono",
"Go to web site" => "Vai al sito web",
"Delete URL" => "Elimina URL",
"View on map" => "Visualizza sulla mappa",
"Delete address" => "Elimina indirizzo",
"1600 Pennsylvania Avenue, NW" => "1600 Pennsylvania Avenue, NW",
"Street address" => "Indirizzo",
"20500" => "20500",
"Postal code" => "CAP",
"Washington, DC" => "Washington, DC",
"City" => "Città",
"District of Columbia" => "District of Columbia",
"State or province" => "Stato o regione",
"USA" => "USA",
"Country" => "Stato",
"Instant Messenger" => "Client di messaggistica istantanea",
"Delete IM" => "Elimina IM",
"Active" => "Attivo",
"Share" => "Condividi",
"Export" => "Esporta",
"CardDAV link" => "Collegamento CardDav",
"CardDAV syncing addresses" => "Indirizzi di sincronizzazione CardDAV",
"more info" => "ulteriori informazioni",
"Primary address (Kontact et al)" => "Indirizzo principale (Kontact e altri)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Rubriche",
"New Address Book" => "Nuova rubrica",
"Description" => "Descrizione"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/it.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Contatti",
"Add new LDAP Addressbook" => "Aggiungi una nuova rubrica LDAP",
"Ok" => "Ok",
"Cancel" => "Annulla",
"Save" => "Salva",
"Edit Addressbook" => "Modifica rubrica",
"Starting file import" => "Inizio importazione file",
"Format selected: {format}" => "Formato selezionato: {format}",
"Automatic format detection" => "Rilevamento automatico del formato",
"Processing {count}/{total} cards" => "Elaborazione di {count}/{total} schede",
"Total:{total}, Success:{imported}, Errors:{failed}" => "Totale:{total}, riusciti:{imported}, errori:{failed}",
"An address book called {name} already exists" => "Una rubrica con nome {name} esiste già",
"Failed adding address book: {error}" => "Aggiunta della rubrica non riuscita: {error}",
"Failed loading address books: {error}" => "Caricamento rubriche non riuscito: {error}",
"Server error! Please inform system administator" => "Errore del server. Informa l'amministratore di sistema",
"Indexing contacts" => "Indicizzazione dei contatti",
"Unrecoverable error loading address books: {msg}" => "Errore irreversibile durante il caricamento delle rubriche: {msg}",
"Error." => "Errore.",
"Add to..." => "Aggiungi a...",
"Remove from..." => "Rimuovi da...",
"Add group..." => "Aggiungi gruppo...",
"Invalid URL: \"{url}\"" => "URL non valido: \"{url}\"",
"Invalid email: \"{url}\"" => "Email non valida: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Unione non riuscita. Impossibile trovare il contatto: {id}",
"Merge failed." => "Unione non riuscita.",
"Merge failed. Error saving contact." => "Unione non riuscita. Errore durante il salvataggio del contatto.",
"Select photo" => "Seleziona la foto",
"Network or server error. Please inform administrator." => "Errore di rete o del server. Informa l'amministratore.",
"Only images can be used as contact photos" => "Solo le immagini possono essere utilizzate come foto dei contatti",
"The size of \"{filename}\" exceeds the maximum allowed {size}" => "La dimensione di \"{filename}\" supera il massimo consentito di {size}",
"Error adding to group." => "Errore durante l'aggiunta al gruppo.",
"Error removing from group." => "Errore durante la rimozione dal gruppo.",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "Hai selezionato più di 300 contatti.\nL'operazione potrebbe non riuscire! Fai clic qui per provare comunque.",
"Error setting {name} as favorite." => "Errore durante l'impostazione di {name} come preferito.",
"Merge contacts" => "Unisci contatti",
"Add group" => "Aggiungi gruppo",
"OK" => "OK",
"Could not find contact: {id}" => "Impossibile trovare il contatto: {id}",
"Edit profile picture" => "Modifica l'immagine del profilo",
"Crop photo" => "Ritaglia foto",
"Error parsing date: {date}" => "Errore durante l'elaborazione della data: {date}",
"# groups" => "# gruppi",
"Error parsing birthday {bday}" => "Errore durante l'elaborazione della data di nascita {bday}",
"The backend does not support multi-byte characters." => "Il motore non supporta i caratteri multi-byte.",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Alcuni contatti sono marcati per l'eliminazione, ma non sono stati ancora rimossi. Attendi fino al completamento dell'operazione.",
"Click to undo deletion of {num} contacts" => "Un clic per annullare l'eliminazione di {num} contatti",
"Cancelled deletion of {num} contacts" => "Eliminazione di {num} contatti annullata",
"Add" => "Aggiungi",
"Contact is already in this group." => "Il contatto è già in questo gruppo.",
"Contacts are already in this group." => "I contatti sono già in questo gruppo.",
"Couldn't get contact list." => "Impossibile ottenere l'elenco dei contatti.",
"Contact is not in this group." => "Il contatto non è in questo gruppo.",
"Contacts are not in this group." => "I contatti non sono in questo gruppo.",
"A group named \"{group}\" already exists" => "Un gruppo con nome \"{group}\" esiste già",
"Failed renaming group: {error}" => "Rinomina gruppo non riuscita: {error}",
"You can drag groups to\narrange them as you like." => "Puoi trascinare i gruppi per\norganizzarli come preferisci.",
"Failed adding group: {error}" => "Aggiunta gruppo non riuscita: {error}",
"All" => "Tutti",
"Favorites" => "Preferiti",
"Shared by {owner}" => "Condiviso da {owner}",
"Not grouped" => "Non raggruppati",
"Failed loading groups: {error}" => "Caricamento gruppi non riuscito: {error}",
"Please choose the addressbook" => "Scegli la rubrica",
"Import into..." => "Importa in...",
"Error loading import template" => "Errore durante il caricamento del modello di importazione",
"Import contacts" => "Importa contatti",
"Import" => "Importa",
"Importing..." => "Importazione in corso...",
"Import done" => "Importazione completata",
"Close" => "Chiudi",
"Error, missing parameters: " => "Errore, parametro mancante:",
"Failed loading photo: {error}" => "Caricamento foto non riuscito: {error}",
"You do not have permissions to see this contact" => "Non hai i permessi per vedere questo contatto",
"Contact not found" => "Contatto non trovato",
"You do not have permissions to see these contacts" => "Non hai i permessi per vedere questi contatti",
"You do not have permissions add contacts to the address book" => "Non hai i permessi per aggiungere contatti alla rubrica",
"The backend for this address book does not support adding contacts" => "Il motore per questa rubrica non supporta l'aggiunta di contatti",
"You do not have permissions to delete this contact" => "Non hai i permessi per eliminare questo contatto",
"The backend for this address book does not support deleting contacts" => "Il motore per questa rubrica non supporta l'eliminazione di contatti",
"Unknown error" => "Errore sconosciuto",
"Access denied" => "Accesso negato",
"The backend for this address book does not support updating" => "Il motore per questa rubrica non supporta l'aggiornamento",
"You don't have permissions to delete the address book." => "Non hai i permessi per eliminare la rubrica.",
"Address book not found" => "Rubrica non trovata.",
"You do not have permissions to update this contact" => "Non hai i permessi per aggiornare questo contatto",
"The backend for this contact does not support updating it" => "Il motore per questo contatto non supporta l'aggiornamento",
"This backend does not support adding contacts" => "Questo motore non supporta l'aggiunta di contatti",
"Property not found" => "Proprietà non trovata",
" Missing IM parameter for: " => "Parametro IM mancante per:",
"Unknown IM: " => "IM sconosciuto:",
"{name}'s Birthday" => "Compleanno di {name}",
"Error creating address book" => "Errore durante la creazione della rubrica",
"The \"%s\" backend does not support deleting address books" => "Il motore \"%s\" non supporta l'eliminazione delle rubriche",
"You do not have permissions to delete the \"%s\" address book" => "Non hai i permessi per eliminare la rubrica \"%s\"",
"Error deleting address book" => "Errore durante l'eliminazione della rubrica",
"Error creating contact." => "Errore durante la creazione del contatto.",
"Error creating contact" => "Errore durante la creazione del contatto",
"Error deleting contact" => "Errore durante l'eliminazione del contatto",
"Error retrieving contact" => "Errore durante il recupero del contatto",
"Error saving contact" => "Errore durante il salvataggio del contatto",
"Error removing contact from other address book." => "Errore durante la rimozione del contatto da altre rubriche.",
"Error getting moved contact" => "Errore durante il recupero del contatto spostato",
"Couldn't find contact." => "Impossibile trovare il contatto.",
"No contact data in request." => "Non ci sono dati di contatto nella richiesta.",
"Error merging into contact." => "Errore durante l'unione al contatto.",
"Error saving contact to backend." => "Errore di salvataggio del contatto nel motore.",
"Property name is not set." => "Il nome della proprietà non è impostato.",
"Property checksum is not set." => "La proprietà del codice di controllo non è impostata.",
"Information about vCard is incorrect. Please reload the page." => "Informazioni sulla vCard non corrette. Ricarica la pagina.",
"Error updating contact" => "Errore durante l'aggiornamento del contatto",
"Error saving contact to backend" => "Errore durante il salvataggio del contatto nel motore",
"Error getting user photo" => "Errore durante il recupero della foto dell'utente",
"No photo path was submitted." => "Non è stato inviato alcun percorso a una foto.",
"Error loading image from cache" => "Errore durante il caricamento dell'immagine dalla cache",
"Error getting PHOTO property." => "Errore di recupero della proprietà FOTO.",
"Error saving contact." => "Errore di salvataggio del contatto.",
"No group name given." => "Nessun nome di gruppo fornito.",
"Error adding group." => "Errore durante l'aggiunta del gruppo.",
"No group name to rename from given." => "Non è stato fornito nessun nome per il gruppo da rinominare.",
"No group name to rename to given." => "Nessun nome gruppo di destinazione fornito.",
"Error renaming group." => "Errore durante la rinomina del gruppo.",
"Group ID missing from request." => "ID del gruppo mancante nella richiesta.",
"Group name missing from request." => "Nome del gruppo mancante nella richiesta.",
"Contact ID missing from request." => "ID del contatta mancante nella richiesta.",
"No file was uploaded. Unknown error" => "Nessun file è stato inviato. Errore sconosciuto",
"There is no error, the file uploaded with success" => "Non ci sono errori, il file è stato caricato correttamente",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Il file inviato supera la direttiva upload_max_filesize nel php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Il file inviato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
"The uploaded file was only partially uploaded" => "Il file è stato caricato solo parzialmente",
"No file was uploaded" => "Nessun file è stato caricato",
"Missing a temporary folder" => "Manca una cartella temporanea",
"Failed to write to disk" => "Scrittura su disco non riuscita",
"Not enough storage available" => "Spazio di archiviazione insufficiente",
"Attempt to upload blacklisted file:" => "Tentativo di caricare un file della lista nera:",
"Error uploading contacts to storage." => "Errore di invio dei contatti in archivio.",
"Error moving file to imports folder." => "Errore durante lo spostamento del file nella cartella di importazione.",
"You do not have permissions to import into this address book." => "Non hai i permessi per importare in questa rubrica.",
"File name missing from request." => "Manca il nome del file nella richiesta.",
"Progress key missing from request." => "Manca la chiave di avanzamento nella richiesta.",
"Attempt to access blacklisted file:" => "Tentativo di accedere a un file della lista nera:",
"No key is given." => "Nessuna chiave fornita.",
"No value is given." => "Nessun valore fornito.",
"Could not set preference: " => "Impossibile impostare la preferenza:",
"Contact" => "Contatto",
"Other" => "Altro",
"HomePage" => "Pagina principale",
"Jabber" => "Jabber",
"Internet call" => "Chiamata via Internet",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "Lavoro",
"Home" => "Casa",
"Mobile" => "Cellulare",
"Text" => "Testo",
"Voice" => "Voce",
"Message" => "Messaggio",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Cercapersone",
"Internet" => "Internet",
"Friends" => "Amici",
"Family" => "Famiglia",
"Enable LDAP Backend" => "Abilita il motore LDAP",
"Enable LDAP backend for the contacts application" => "Abilita il motore LDAP per l'applicazione dei contatti",
"Warning: LDAP Backend is in beta mode, use with precautions" => "Avviso: il motore LDAP è in fase di beta, utilizzalo con cautela",
"New contact" => "Nuovo contatto",
"Group name" => "Nome gruppo",
"New group" => "Nuovo gruppo",
"Address books" => "Rubriche",
"Display name" => "Nome visualizzato",
"Add Address Book" => "Aggiungi rubrica",
"Add LDAP Address Book" => "Aggiungi rubrica LDAP",
"Automatic format" => "Formato automatico",
"Select file..." => "Seleziona file...",
"(De-)select all" => "(De)seleziona tutto",
"Sort order" => "Ordinamento",
"First- Lastname" => "Nome Cognome",
"Last-, Firstname" => "Cognome, Nome",
"Delete" => "Elimina",
"Groups" => "Gruppi",
"Download" => "Scarica",
"Merge" => "Unisci",
"Email" => "Posta elettronica",
"Phone" => "Telefono",
"Address" => "Indirizzo",
"Group" => "Gruppo",
"Keyboard shortcuts" => "Scorciatoie da tastiera",
"Navigation" => "Navigazione",
"Next contact in list" => "Contatto successivo in elenco",
"Previous contact in list" => "Contatto precedente in elenco",
"Expand/collapse current addressbook" => "Espandi/Contrai la rubrica corrente",
"Next addressbook" => "Rubrica successiva",
"Previous addressbook" => "Rubrica precedente",
"Actions" => "Azioni",
"Refresh contacts list" => "Aggiorna l'elenco dei contatti",
"Add new contact" => "Aggiungi un nuovo contatto",
"Add new addressbook" => "Aggiungi una nuova rubrica",
"Delete current contact" => "Elimina il contatto corrente",
"You have no contacts in your address book or your address book is disabled." => "Non hai contatti nella rubrica o la tua rubrica è disabilitata.",
"Add a new contact or import existing contacts from a VCF file." => "Aggiungi un nuovo contatto o importa contatti esistenti da un file VCF.",
"Which contact should the data be merged into?" => "A quale contatto desideri unire i dati?",
"Delete the other(s) after successful merge?" => "Vuoi eliminare gli altri dopo il completamento dell'unione?",
"Compose mail" => "Componi messaggio",
"Delete current photo" => "Elimina la foto corrente",
"Edit current photo" => "Modifica la foto corrente",
"Upload new photo" => "Invia una nuova foto",
"Select photo from Files" => "Seleziona foto da File",
"Favorite" => "Preferito",
"Name" => "Nome",
"First name" => "Nome",
"Additional names" => "Nomi aggiuntivi",
"Last name" => "Cognome",
"Address book" => "Rubrica",
"Nickname" => "Pseudonimo",
"Title" => "Titolo",
"Organization" => "Organizzazione",
"Birthday" => "Compleanno",
"Website" => "Sito web",
"Instant messaging" => "Messaggistica istantanea",
"Notes go here..." => "Le note vanno qui...",
"Add field..." => "Aggiungi campo...",
"Instant Messaging" => "Messaggistica istantanea",
"Note" => "Nota",
"Web site" => "Sito web",
"Preferred" => "Preferito",
"Please specify a valid email address." => "Specifica un indirizzo email valido",
"someone@example.com" => "qualcuno@esempio.com",
"Mail to address" => "Invia per email",
"Delete email address" => "Elimina l'indirizzo email",
"Enter phone number" => "Inserisci il numero di telefono",
"Go to web site" => "Vai al sito web",
"View on map" => "Visualizza sulla mappa",
"Street address" => "Indirizzo",
"Postal code" => "CAP",
"City" => "Città",
"State or province" => "Stato o regione",
"Country" => "Stato",
"Instant Messenger" => "Client di messaggistica istantanea",
"Active" => "Attivo",
"Share" => "Condividi",
"Export" => "Esporta",
"CardDAV link" => "Collegamento CardDav",
"Edit" => "Modifica",
"Addressbook URI" => "URI della rubrica",
"URI" => "URI",
"Description" => "Descrizione",
"LDAP URL" => "URL LDAP",
"Anonymous" => "Anonimo",
"Read-only" => "Sola lettura",
"Read-Only" => "Sola lettura",
"User" => "Utente",
"Password" => "Password",
"Page size" => "Dimensioni della pagina",
"Base DN for search" => "DN base per le ricerche",
"Base DN" => "DN base",
"Search filter" => "Filtro di ricerca",
"Filter" => "Filtro",
"Base DN for modification" => "DN base per le modifiche",
"Base DN modification" => "Modifica DN base",
"Connector" => "Connettore",
"Connector value (Better use external editor and copy/paste)" => "Valore del connettore (meglio utilizzare un editor esterno e copia/incolla)",
"Copy from (Warning, replaces current custom value)" => "Copia da (attenzione, sostituisce i valori attuali personalizzati)"
);
